"""
记录日志
"""

import os
import logging


def logger(filepath=None):
    """
    生成logger实例
    :return: logger实例
    """
    if (not filepath) or (not os.path.isfile(filepath)):
        filepath = 'log_by_yucctools.log'
    # create logger with a name
    logger = logging.getLogger()
    if not logger.handlers:
        logger.setLevel(logging.DEBUG)
        formatter = logging.Formatter(
                '%(asctime)s %(filename)s:%(lineno)5s %(funcName)20s() %(levelname)-8s %(message)s')
        # create file handler which logs even debug messages
        fh = logging.FileHandler(filepath, encoding='utf-8')
        fh.setLevel(10)
        fh.setFormatter(formatter)
        logger.addHandler(fh)

        ch = logging.StreamHandler()
        ch.setLevel(10)
        ch.setFormatter(formatter)
        logger.addHandler(ch)
    return logger



from setuptools import setup

import shutil
from pathlib import Path

# Remove stale transformers.egg-info directory to avoid https://github.com/pypa/pip/issues/5466
stale_egg_info = Path(__file__).parent / "yucctools.egg-info"
if stale_egg_info.exists():
    shutil.rmtree(stale_egg_info)

stale_dist = Path(__file__).parent / "dist"
if stale_dist.exists():
    shutil.rmtree(stale_dist)



setup(name='yucctools',
        version='0.1.1',
        description='useful tools, such as logger',
        long_description=open('README.md', 'r', encoding='utf-8').read(),
        long_description_content_type='text/markdown',
        url='https://github.com/yucc2018/yucctools',
        author='Chen-Chen Yu',
        author_email='6506666@gmail.com',
        license='MIT',
        packages=['yucctools'],
        zip_safe=False)

